@@ -134,6 +134,10 @@ der_decode(DER) when is_binary(DER) ->
 	case Result of
 		PrivateKeyInfo=#'PrivateKeyInfo'{} ->
 			i2k(PrivateKeyInfo);
+		ECPrivateKey={'ECPrivateKey', _, _, _, _, _} -> %% OTP 24
+			i2k(ECPrivateKey);
+		ECPrivateKey={'ECPrivateKey', _, _, _, _} -> %% OTP 23
+			i2k(ECPrivateKey);
 		SubjectPublicKeyInfo=#'SubjectPublicKeyInfo'{} ->
 			i2k(SubjectPublicKeyInfo);
 		Other ->
@@ -198,6 +202,10 @@ pem_entry_decode(PEMEntry) ->
 	case Result of
 		PrivateKeyInfo=#'PrivateKeyInfo'{} ->
 			i2k(PrivateKeyInfo);
+		ECPrivateKey={'ECPrivateKey', _, _, _, _, _} -> %% OTP 24
+			i2k(ECPrivateKey);
+		ECPrivateKey={'ECPrivateKey', _, _, _, _} -> %% OTP 23
+			i2k(ECPrivateKey);
 		SubjectPublicKeyInfo=#'SubjectPublicKeyInfo'{} ->
 			i2k(SubjectPublicKeyInfo);
 		Other ->
@@ -220,6 +228,10 @@ pem_entry_decode(PEMEntry, Password) ->
 	case Result of
 		PrivateKeyInfo=#'PrivateKeyInfo'{} ->
 			i2k(PrivateKeyInfo);
+		ECPrivateKey={'ECPrivateKey', _, _, _, _, _} -> %% OTP 24
+			i2k(ECPrivateKey);
+		ECPrivateKey={'ECPrivateKey', _, _, _, _} -> %% OTP 23
+			i2k(ECPrivateKey);
 		SubjectPublicKeyInfo=#'SubjectPublicKeyInfo'{} ->
 			i2k(SubjectPublicKeyInfo);
 		Other ->
@@ -366,7 +378,7 @@ pem_dec_entry(Start, Lines) ->
 %% @private
 decode_encrypted_private_keyinfo(Der) ->
 	#'EncryptedPrivateKeyInfo'{encryptionAlgorithm = AlgorithmInfo, encryptedData = Data} = der_decode('EncryptedPrivateKeyInfo', Der),
-	DecryptParams = decrypt_parameters(AlgorithmInfo), 
+	DecryptParams = decrypt_parameters(AlgorithmInfo),
 	{true, {'PrivateKeyInfo', Data, DecryptParams}}.
 
 %% @private
@@ -624,31 +636,31 @@ pem_entry_enc1(_, _, _) ->
 %% @private
 pem_cipher(Data, {Cipher = "AES-128-CBC", KeyDevParams}, Password) ->
 	{Key, IV} = password_to_key_and_iv(Password, Cipher, KeyDevParams),
-	{true, crypto:block_encrypt(aes_cbc128, Key, IV, jose_jwa_pkcs7:pad(Data))};
+	{true, jose_crypto_compat:crypto_one_time(aes_128_cbc, Key, IV, jose_jwa_pkcs7:pad(Data), true)};
 pem_cipher(Data, {Cipher = "AES-192-CBC", KeyDevParams}, Password) ->
 	{Key, IV} = password_to_key_and_iv(Password, Cipher, KeyDevParams),
-	{true, crypto:block_encrypt(aes_cbc192, Key, IV, jose_jwa_pkcs7:pad(Data))};
+	{true, jose_crypto_compat:crypto_one_time(aes_192_cbc, Key, IV, jose_jwa_pkcs7:pad(Data), true)};
 pem_cipher(Data, {Cipher = "AES-256-CBC", KeyDevParams}, Password) ->
 	{Key, IV} = password_to_key_and_iv(Password, Cipher, KeyDevParams),
-	{true, crypto:block_encrypt(aes_cbc256, Key, IV, jose_jwa_pkcs7:pad(Data))};
+	{true, jose_crypto_compat:crypto_one_time(aes_256_cbc, Key, IV, jose_jwa_pkcs7:pad(Data), true)};
 pem_cipher(_, _, _) ->
 	false.
 
 %% @private
 pem_decipher(Data, {Cipher = "AES-128-CBC", KeyDevParams}, Password) ->
 	{Key, IV} = password_to_key_and_iv(Password, Cipher, KeyDevParams),
-	{true, crypto:block_decrypt(aes_cbc128, Key, IV, Data)};
+	{true, jose_crypto_compat:crypto_one_time(aes_128_cbc, Key, IV, Data, false)};
 pem_decipher(Data, {Cipher = "AES-192-CBC", KeyDevParams}, Password) ->
 	{Key, IV} = password_to_key_and_iv(Password, Cipher, KeyDevParams),
-	{true, crypto:block_decrypt(aes_cbc192, Key, IV, Data)};
+	{true, jose_crypto_compat:crypto_one_time(aes_192_cbc, Key, IV, Data, false)};
 pem_decipher(Data, {Cipher = "AES-256-CBC", KeyDevParams}, Password) ->
 	{Key, IV} = password_to_key_and_iv(Password, Cipher, KeyDevParams),
-	{true, crypto:block_decrypt(aes_cbc256, Key, IV, Data)};
+	{true, jose_crypto_compat:crypto_one_time(aes_256_cbc, Key, IV, Data, false)};
 pem_decipher(_, _, _) ->
 	false.
 
 %% @private
-ceiling(Float) -> 
+ceiling(Float) ->
 	erlang:round(Float + 0.5).
 
 %% @private
@@ -760,6 +772,22 @@ i2k(#'PrivateKeyInfo'{
 		publicKey = #'jose_EdDSA25519PublicKey'{ publicKey = PublicKey },
 		privateKey = PrivateKey
 	};
+i2k({'ECPrivateKey', _,
+	 << 4, 32:8/integer, PrivateKey:32/binary >>,
+	 {namedCurve, ?'jose_id-EdDSA25519'}, _, _}) ->
+	PublicKey = jose_curve25519:eddsa_secret_to_public(PrivateKey),
+	#'jose_EdDSA25519PrivateKey'{
+	    publicKey = #'jose_EdDSA25519PublicKey'{ publicKey = PublicKey },
+	    privateKey = PrivateKey
+	};
+i2k({'ECPrivateKey', _,
+	 << 4, 32:8/integer, PrivateKey:32/binary >>,
+	 {namedCurve, ?'jose_id-EdDSA25519'}, _, _, _}) ->
+	PublicKey = jose_curve25519:eddsa_secret_to_public(PrivateKey),
+	#'jose_EdDSA25519PrivateKey'{
+	    publicKey = #'jose_EdDSA25519PublicKey'{ publicKey = PublicKey },
+	    privateKey = PrivateKey
+	};
 i2k(#'SubjectPublicKeyInfo'{
 	algorithm =
 		#'AlgorithmIdentifier'{
@@ -781,6 +809,22 @@ i2k(#'PrivateKeyInfo'{
 		publicKey = #'jose_EdDSA448PublicKey'{ publicKey = PublicKey },
 		privateKey = PrivateKey
 	};
+i2k({'ECPrivateKey', _,
+	 << 4, 57:8/integer, PrivateKey:57/binary >>,
+	 {namedCurve, ?'jose_id-EdDSA448'}, _, _}) ->
+	PublicKey = jose_curve448:eddsa_secret_to_public(PrivateKey),
+	#'jose_EdDSA448PrivateKey'{
+		publicKey = #'jose_EdDSA448PublicKey'{ publicKey = PublicKey },
+		privateKey = PrivateKey
+	};
+i2k({'ECPrivateKey', _,
+	 << 4, 57:8/integer, PrivateKey:57/binary >>,
+	 {namedCurve, ?'jose_id-EdDSA448'}, _, _, _}) ->
+	PublicKey = jose_curve448:eddsa_secret_to_public(PrivateKey),
+	#'jose_EdDSA448PrivateKey'{
+		publicKey = #'jose_EdDSA448PublicKey'{ publicKey = PublicKey },
+		privateKey = PrivateKey
+	};
 i2k(#'SubjectPublicKeyInfo'{
 	algorithm =
 		#'AlgorithmIdentifier'{
