@@ -736,41 +736,41 @@ init_per_group(G='nist-800-56A', Config) ->
 			<<86,170,141,234,248,35,109,32,92,34,40,205,113,167,16,26>>},
 		%% See [https://bitbucket.org/b_c/jose4j/src/cb968fdb10bdef6ecedf279b030f9b3af59f5e8e/src/test/java/org/jose4j/jwe/kdf/ConcatKeyDerivationFunctionTest.java]
 		{sha256,
-			base64url:decode(<<"Sq8rGLm4rEtzScmnSsY5r1n-AqBl_iBU8FxN80Uc0S0">>),
+			jose_jwa_base64url:decode(<<"Sq8rGLm4rEtzScmnSsY5r1n-AqBl_iBU8FxN80Uc0S0">>),
 			{<<"A256CBC-HS512">>,
 				<<>>,
 				<<>>,
 				<< 0, 0, 2, 0 >>,
 				<<>>},
 			512,
-			base64url:decode(<<"pgs50IOZ6BxfqvTSie4t9OjWxGr4whiHo1v9Dti93CRiJE2PP60FojLatVVrcjg3BxpuFjnlQxL97GOwAfcwLA">>)},
+			jose_jwa_base64url:decode(<<"pgs50IOZ6BxfqvTSie4t9OjWxGr4whiHo1v9Dti93CRiJE2PP60FojLatVVrcjg3BxpuFjnlQxL97GOwAfcwLA">>)},
 		{sha256,
-			base64url:decode(<<"LfkHot2nGTVlmfxbgxQfMg">>),
+			jose_jwa_base64url:decode(<<"LfkHot2nGTVlmfxbgxQfMg">>),
 			{<<"A128CBC-HS256">>,
 				<<>>,
 				<<>>,
 				<< 0, 0, 1, 0 >>,
 				<<>>},
 			256,
-			base64url:decode(<<"vphyobtvExGXF7TaOvAkx6CCjHQNYamP2ET8xkhTu-0">>)},
+			jose_jwa_base64url:decode(<<"vphyobtvExGXF7TaOvAkx6CCjHQNYamP2ET8xkhTu-0">>)},
 		{sha256,
-			base64url:decode(<<"KSDnQpf2iurUsAbcuI4YH-FKfk2gecN6cWHTYlBzrd8">>),
+			jose_jwa_base64url:decode(<<"KSDnQpf2iurUsAbcuI4YH-FKfk2gecN6cWHTYlBzrd8">>),
 			{<<"meh">>,
 				<<"Alice">>,
 				<<"Bob">>,
 				<< 0, 0, 4, 0 >>,
 				<<>>},
 			1024,
-			base64url:decode(<<"yRbmmZJpxv3H1aq3FgzESa453frljIaeMz6pt5rQZ4Q5Hs-4RYoFRXFh_qBsbTjlsj8JxIYTWj-cp5LKtgi1fBRsf_5yTEcLDv4pKH2fNxjbEOKuVVDWA1_Qv2IkEC0_QSi3lSSELcJaNX-hDG8occ7oQv-w8lg6lLJjg58kOes">>)},
+			jose_jwa_base64url:decode(<<"yRbmmZJpxv3H1aq3FgzESa453frljIaeMz6pt5rQZ4Q5Hs-4RYoFRXFh_qBsbTjlsj8JxIYTWj-cp5LKtgi1fBRsf_5yTEcLDv4pKH2fNxjbEOKuVVDWA1_Qv2IkEC0_QSi3lSSELcJaNX-hDG8occ7oQv-w8lg6lLJjg58kOes">>)},
 		{sha256,
-			base64url:decode(<<"zp9Hot2noTVlmfxbkXqfn1">>),
+			jose_jwa_base64url:decode(<<"zp9Hot2noTVlmfxbkXqfn1">>),
 			{<<"A192CBC-HS384">>,
 				<<>>,
 				<<>>,
 				<< 0, 0, 1, 128 >>,
 				<<>>},
 			384,
-			base64url:decode(<<"SNOvl6h5iSYWJ_EhlnvK8o6om9iyR8HkKMQtQYGkYKkVY0HFMleoUm-H6-kLz8sW">>)}
+			jose_jwa_base64url:decode(<<"SNOvl6h5iSYWJ_EhlnvK8o6om9iyR8HkKMQtQYGkYKkVY0HFMleoUm-H6-kLz8sW">>)}
 	],
 	[{vectors, Vectors} | jose_ct:start(G, Config)];
 init_per_group(G='pkcs-1v2-1-vec', Config) ->
