@@ -11,7 +11,7 @@
 base64url_binary() ->
 	?LET(Binary,
 		binary(),
-		base64url:encode(Binary)).
+		jose_jwa_base64url:encode(Binary)).
 
 binary_map() ->
 	?LET(List,
@@ -44,6 +44,21 @@ jwk_gen() ->
 		jwk_map(),
 		{Keys, jose_jwk:from_map(AlicePrivateJWKMap)}).
 
+prop_from_der_and_to_der() ->
+	?FORALL({_Keys, AlicePrivateJWK, Password},
+		?LET({{Keys, AlicePrivateJWK}, Bytes},
+			{jwk_gen(), binary()},
+			{Keys, AlicePrivateJWK, jose_jwa_base64url:encode(Bytes)}),
+		begin
+			AlicePrivateDER = element(2, jose_jwk:to_der(AlicePrivateJWK)),
+			EncryptedAlicePrivateDER = element(2, jose_jwk:to_der(Password, AlicePrivateJWK)),
+			AlicePublicJWK = jose_jwk:to_public(AlicePrivateJWK),
+			AlicePublicDER = element(2, jose_jwk:to_der(AlicePublicJWK)),
+			AlicePrivateJWK =:= jose_jwk:from_der(AlicePrivateDER)
+			andalso AlicePrivateJWK =:= jose_jwk:from_der(Password, EncryptedAlicePrivateDER)
+			andalso AlicePublicJWK =:= jose_jwk:from_der(AlicePublicDER)
+		end).
+
 prop_from_map_and_to_map() ->
 	?FORALL({{{AlicePrivateKey, AlicePublicKey}, _}, AlicePrivateJWKMap},
 		?LET({{Keys, JWKMap}, Extras},
@@ -65,7 +80,7 @@ prop_from_pem_and_to_pem() ->
 	?FORALL({_Keys, AlicePrivateJWK, Password},
 		?LET({{Keys, AlicePrivateJWK}, Bytes},
 			{jwk_gen(), binary()},
-			{Keys, AlicePrivateJWK, base64url:encode(Bytes)}),
+			{Keys, AlicePrivateJWK, jose_jwa_base64url:encode(Bytes)}),
 		begin
 			AlicePrivatePEM = element(2, jose_jwk:to_pem(AlicePrivateJWK)),
 			EncryptedAlicePrivatePEM = element(2, jose_jwk:to_pem(Password, AlicePrivateJWK)),
